==> rtracklayer_1.4.1.tar.gz: rtracklayer/man/browserView-methods.Rd <==
\name{browserView-methods}
\docType{methods}
\alias{browserView}
\alias{browserView-methods}
\alias{browserView,UCSCSession-method}
\title{Getting browser views}
\description{
  Methods for creating and getting browser views.
}
\usage{
  browserView(object, range, track, ...)
}
\arguments{
  \item{object}{The object from which to get the views.}
  \item{range}{The \code{\link[BSgenome:RangesList-methods]{RangesList}} to display.}
  \item{track}{List of track names to make visible in the view.}
  \item{\dots}{Arguments to pass to methods}
}
\section{Methods}{
  The following methods are defined by \pkg{rtracklayer}. 
  \describe{
    
    \item{object = "UCSCSession"}{ \code{browserView(object, range =
        range(object), track = trackNames(object), imagewidth = 800,
        ...)}: Creates a 
      \code{\linkS4class{BrowserView}} of \code{range} with visible
      tracks specified by \code{track}. The \code{imagewidth} parameter
      specifies the width of the track image in pixels. \code{track}
      may be an instance 
      of \code{\linkS4class{UCSCTrackModes}}. Arguments in \code{...}
      are passed to \code{\link{ucscTrackModes}} to create the
      \code{UCSCTrackModes} instance that will override modes
      indicated by the \code{track} parameter.
   }
    
}}
\examples{
\dontrun{
  session <- browserSession()
  browserView(session, GenomicRanges(20000, 50000, "chr2"))
  ## only view "knownGene" track
  browserView(session, track = "knownGene")
}
}
\keyword{methods}

==> rtracklayer_1.6.0.tar.gz: rtracklayer/man/browserView-methods.Rd <==
\name{browserView-methods}
\docType{methods}
\alias{browserView}
\alias{browserView-methods}
\alias{browserView,UCSCSession-method}
\title{Getting browser views}
\description{
  Methods for creating and getting browser views.
}
\usage{
  browserView(object, range, track, ...)
}
\arguments{
  \item{object}{The object from which to get the views.}
  \item{range}{The \code{\link[IRanges:RangesList-class]{RangesList}} to
    display.} 
  \item{track}{List of track names to make visible in the view.}
  \item{\dots}{Arguments to pass to methods}
}
\section{Methods}{
  The following methods are defined by \pkg{rtracklayer}. 
  \describe{
    
    \item{object = "UCSCSession"}{ \code{browserView(object, range =
        range(object), track = trackNames(object), imagewidth = 800,
        ...)}: Creates a 
      \code{\linkS4class{BrowserView}} of \code{range} with visible
      tracks specified by \code{track}. The \code{imagewidth} parameter
      specifies the width of the track image in pixels. \code{track}
      may be an instance 
      of \code{\linkS4class{UCSCTrackModes}}. Arguments in \code{...}
      are passed to \code{\link{ucscTrackModes}} to create the
      \code{UCSCTrackModes} instance that will override modes
      indicated by the \code{track} parameter.
   }
    
}}
\examples{
\dontrun{
  session <- browserSession()
  browserView(session, GenomicRanges(20000, 50000, "chr2"))
  ## only view "knownGene" track
  browserView(session, track = "knownGene")
}
}
\keyword{methods}
